@@ -69,7 +69,7 @@ def get_callable_cells(function):
                 callables.extend(get_callable_cells(closure.cell_contents))
             else:
                 callables.append(closure.cell_contents)
-    return callables
+    return [function] + callables
 
 def get_tests(function):
     """
